summaryrefslogtreecommitdiff
path: root/layout/style/StyleAnimationValue.h
diff options
context:
space:
mode:
Diffstat (limited to 'layout/style/StyleAnimationValue.h')
-rw-r--r--layout/style/StyleAnimationValue.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/layout/style/StyleAnimationValue.h b/layout/style/StyleAnimationValue.h
index e318cecb6b..af58daac13 100644
--- a/layout/style/StyleAnimationValue.h
+++ b/layout/style/StyleAnimationValue.h
@@ -55,7 +55,7 @@ public:
* @param aCount The number of times to add aValueToAdd.
* @return true on success, false on failure.
*/
- static MOZ_MUST_USE bool
+ [[nodiscard]] static bool
Add(nsCSSPropertyID aProperty, StyleAnimationValue& aDest,
const StyleAnimationValue& aValueToAdd, uint32_t aCount) {
return AddWeighted(aProperty, 1.0, aDest, aCount, aValueToAdd, aDest);
@@ -93,7 +93,7 @@ public:
* @param aDistance The result of the calculation.
* @return true on success, false on failure.
*/
- static MOZ_MUST_USE bool
+ [[nodiscard]] static bool
ComputeDistance(nsCSSPropertyID aProperty,
const StyleAnimationValue& aStartValue,
const StyleAnimationValue& aEndValue,
@@ -116,7 +116,7 @@ public:
* @param [out] aResultValue The resulting interpolated value.
* @return true on success, false on failure.
*/
- static MOZ_MUST_USE bool
+ [[nodiscard]] static bool
Interpolate(nsCSSPropertyID aProperty,
const StyleAnimationValue& aStartValue,
const StyleAnimationValue& aEndValue,
@@ -140,7 +140,7 @@ public:
* difficulty, we might change this to restrict them to being
* positive.
*/
- static MOZ_MUST_USE bool
+ [[nodiscard]] static bool
AddWeighted(nsCSSPropertyID aProperty,
double aCoeff1, const StyleAnimationValue& aValue1,
double aCoeff2, const StyleAnimationValue& aValue2,
@@ -162,7 +162,7 @@ public:
* has a value which is outside the range [0, 1] so that we can calculate
* plausible values as interpolation with the return value.
*/
- static MOZ_MUST_USE bool
+ [[nodiscard]] static bool
Accumulate(nsCSSPropertyID aProperty, StyleAnimationValue& aDest,
const StyleAnimationValue& aValueToAccumulate,
uint64_t aCount);
@@ -199,7 +199,7 @@ public:
* nullptr.
* @return true on success, false on failure.
*/
- static MOZ_MUST_USE bool
+ [[nodiscard]] static bool
ComputeValue(nsCSSPropertyID aProperty,
mozilla::dom::Element* aTargetElement,
nsStyleContext* aStyleContext,
@@ -218,7 +218,7 @@ public:
* to aResult. On failure, aResult might still have partial results
* in it.
*/
- static MOZ_MUST_USE bool
+ [[nodiscard]] static bool
ComputeValues(nsCSSPropertyID aProperty,
mozilla::CSSEnabledState aEnabledState,
mozilla::dom::Element* aTargetElement,
@@ -231,7 +231,7 @@ public:
* A variant on ComputeValues that takes an nsCSSValue as the specified
* value. Only longhand properties are supported.
*/
- static MOZ_MUST_USE bool
+ [[nodiscard]] static bool
ComputeValues(nsCSSPropertyID aProperty,
mozilla::CSSEnabledState aEnabledState,
mozilla::dom::Element* aTargetElement,
@@ -244,7 +244,7 @@ public:
* A variant of ComputeValues that takes a RawServoDeclarationBlock
* as the specified value.
*/
- static MOZ_MUST_USE bool
+ [[nodiscard]] static bool
ComputeValues(nsCSSPropertyID aProperty,
mozilla::CSSEnabledState aEnabledState,
nsStyleContext* aStyleContext,
@@ -268,18 +268,18 @@ public:
* @param [out] aSpecifiedValue The resulting specified value.
* @return true on success, false on failure.
*
* These functions are not MOZ_MUST_USE because failing to check the return
* value is common and reasonable.
*/
- static MOZ_MUST_USE bool
+ static bool
UncomputeValue(nsCSSPropertyID aProperty,
const StyleAnimationValue& aComputedValue,
nsCSSValue& aSpecifiedValue);
- static MOZ_MUST_USE bool
+ static bool
UncomputeValue(nsCSSPropertyID aProperty,
StyleAnimationValue&& aComputedValue,
nsCSSValue& aSpecifiedValue);
- static MOZ_MUST_USE bool
+ static bool
UncomputeValue(nsCSSPropertyID aProperty,
const StyleAnimationValue& aComputedValue,
nsAString& aSpecifiedValue);
@@ -298,7 +298,7 @@ public:
* @param [out] aComputedValue The resulting computed value.
* @return true on success, false on failure.
*/
- static MOZ_MUST_USE bool ExtractComputedValue(
+ [[nodiscard]] static bool ExtractComputedValue(
nsCSSPropertyID aProperty,
nsStyleContext* aStyleContext,
StyleAnimationValue& aComputedValue);
@@ -268,18 +268,18 @@ public:
* @return true on success, false on failure.
*
- * These functions are not MOZ_MUST_USE because failing to check the return
+ * These functions are not [[nodiscard]] because failing to check the return
* value is common and reasonable.
*/